package wenrgise.hrms.ejb.facade;

import java.sql.Timestamp;
import java.util.ArrayList;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import wenrgise.common.bean.BaseHeaderBean;
import wenrgise.common.exception.EnrgiseApplicationException;
import wenrgise.common.exception.EnrgiseSystemException;
import wenrgise.common.utility.RecordMetaInfo;
import wenrgise.common.utility.UserInfo;
import wenrgise.common.vo.LovQueryVO;
import wenrgise.common.vo.LovVO;
import wenrgise.hrms.bean.HrmSepApplnHdrBean;
import wenrgise.hrms.bean.HrmSepCatMstHdrBean;
import wenrgise.hrms.bean.HrmSepClrEmpHdrBean;
import wenrgise.hrms.bean.HrmSepClrTmplMstHdrBean;
import wenrgise.hrms.bean.HrmSepOrderHdrBean;
import wenrgise.hrms.ejb.business.HrmSepApplnBO;
import wenrgise.hrms.ejb.business.HrmSepCatMstBO;
import wenrgise.hrms.ejb.business.HrmSepClrEmpBO;
import wenrgise.hrms.ejb.business.HrmSepClrLstBO;
import wenrgise.hrms.ejb.business.HrmSepClrTmplMstBO;
import wenrgise.hrms.ejb.business.HrmSepOrderBO;
import wenrgise.hrms.vo.HrmSepApplnQVO;
import wenrgise.hrms.vo.HrmSepCatMstQVO;
import wenrgise.hrms.vo.HrmSepClrEmpQVO;
import wenrgise.hrms.vo.HrmSepClrTmplMstQVO;
import wenrgise.hrms.vo.HrmSepOrderQVO;

public class HrmSeparationFacadeBean implements SessionBean {
  SessionContext ctx;
  
  public void ejbCreate() {}
  
  public void ejbActivate() {}
  
  public void ejbPassivate() {}
  
  public void ejbRemove() {}
  
  public void setSessionContext(SessionContext ctx) {
    this.ctx = ctx;
  }
  
  public RecordMetaInfo getHrmSepApplnHdrMetaInfo(HrmSepApplnQVO oHrmSepApplnQVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepApplnHdrMetaInfo(oHrmSepApplnQVO);
  }
  
  public ArrayList getHrmSepApplnHeaderInfo(HrmSepApplnQVO oHrmSepApplnQVO, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepApplnHeaderInfo(oHrmSepApplnQVO, lStartPosition, lLastPosition);
  }
  
  public RecordMetaInfo getHrmSepApplnDtlMetaInfo(String lPrimaryKey) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepApplnDtlMetaInfo(lPrimaryKey);
  }
  
  public ArrayList getHrmSepApplnDetailInfo(String lPrimaryKey, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepApplnDetailInfo(lPrimaryKey, lStartPosition, lLastPosition);
  }
  
  public LovVO getHrmSeparationCodeLOV(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepCatMstBO oHrmSepCatMstBO = new HrmSepCatMstBO();
    return oHrmSepCatMstBO.getHrmSeparationCodeLOV(oLovQueryVO);
  }
  
  public LovVO getHrmSepApplnNoLOVdata(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepApplnNoLOVdata(oLovQueryVO);
  }
  
  public LovVO getHrmSepCategoryLOVdata(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getHrmSepCategoryLOVdata(oLovQueryVO);
  }
  
  public LovVO getSepEmpNoQLOVData(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getSepEmpNoQLOVData(oLovQueryVO);
  }
  
  public LovVO getSepEmpNoNLOVData(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO();
    return oHrmSepApplnBO.getSepEmpNoNLOVData(oLovQueryVO);
  }
  
  public String saveData(HrmSepApplnHdrBean oHrmSepApplnHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO(oUserInfo);
      return oHrmSepApplnBO.saveData((BaseHeaderBean)oHrmSepApplnHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public String approveSepAppln(HrmSepApplnHdrBean oHrmSepApplnHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO(oUserInfo);
      return oHrmSepApplnBO.approveSepAppln((BaseHeaderBean)oHrmSepApplnHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public String rejectSepAppln(HrmSepApplnHdrBean oHrmSepApplnHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepApplnBO oHrmSepApplnBO = new HrmSepApplnBO(oUserInfo);
      return oHrmSepApplnBO.rejectSepAppln((BaseHeaderBean)oHrmSepApplnHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public LovVO getHrmSepOrderNoLOVdata(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderNoLOVdata(oLovQueryVO);
  }
  
  public LovVO getHrmSepOrderApplnNoLOVdata(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderApplnNoLOVdata(oLovQueryVO);
  }
  
  public LovVO getHrmSepOrderApplnNoQLOVdata(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderApplnNoQLOVdata(oLovQueryVO);
  }
  
  public LovVO getSepApprNameLOVData(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getSepApprNameLOVData(oLovQueryVO);
  }
  
  public RecordMetaInfo getHrmSepOrderHdrMetaInfo(HrmSepOrderQVO oHrmSepOrderQVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderHdrMetaInfo(oHrmSepOrderQVO);
  }
  
  public ArrayList getHrmSepOrderHdr(HrmSepOrderQVO oHrmSepOrderQVO, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderHdr(oHrmSepOrderQVO, lStartPosition, lLastPosition);
  }
  
  public RecordMetaInfo getHrmSepOrderDtlMetaInfo(String lPrimaryKey) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderDtlMetaInfo(lPrimaryKey);
  }
  
  public ArrayList getHrmSepOrderDtl(String lPrimaryKey, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO();
    return oHrmSepOrderBO.getHrmSepOrderDtl(lPrimaryKey, lStartPosition, lLastPosition);
  }
  
  public String saveData(HrmSepOrderHdrBean oHrmSepOrderHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO(oUserInfo);
    return oHrmSepOrderBO.saveData((BaseHeaderBean)oHrmSepOrderHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
  }
  
  public String approveSepOrder(HrmSepOrderHdrBean oHrmSepOrderHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO(oUserInfo);
      return oHrmSepOrderBO.approveSepOrder((BaseHeaderBean)oHrmSepOrderHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public String rejectSepOrder(HrmSepOrderHdrBean oHrmSepOrderHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepOrderBO oHrmSepOrderBO = new HrmSepOrderBO(oUserInfo);
      return oHrmSepOrderBO.rejectSepOrder((BaseHeaderBean)oHrmSepOrderHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public RecordMetaInfo getHrmSepCatHeaderMetaInfo(HrmSepCatMstQVO oHrmSepCatMstQVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepCatMstBO oHrmSepCatMstBO = new HrmSepCatMstBO();
    return oHrmSepCatMstBO.getHrmSepCatHdrMetaInfo(oHrmSepCatMstQVO);
  }
  
  public ArrayList getHrmSepCatHeader(HrmSepCatMstQVO oHrmSepCatMstQVO, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepCatMstBO oHrmSepCatMstBO = new HrmSepCatMstBO();
    return oHrmSepCatMstBO.getHrmSepCatHeaderInfo(oHrmSepCatMstQVO, lStartPosition, lLastPosition);
  }
  
  public String saveData(HrmSepCatMstHdrBean oHrmSepCatMstHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepCatMstBO oHrmSepCatMstBO = new HrmSepCatMstBO(oUserInfo);
      return oHrmSepCatMstBO.saveData((BaseHeaderBean)oHrmSepCatMstHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public RecordMetaInfo getHrmSepClrLstDtlMetaInfo() throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrLstBO oHrmSepClrLstBO = new HrmSepClrLstBO();
    return oHrmSepClrLstBO.getHrmSepClrLstDtlMetaInfo();
  }
  
  public ArrayList getHrmSepClrLstDetailInfo(long lDetailFirstPosition, long lDetailLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrLstBO oHrmSepClrLstBO = new HrmSepClrLstBO();
    return oHrmSepClrLstBO.getHrmSepClrLstDetailInfo(lDetailFirstPosition, lDetailLastPosition);
  }
  
  public String saveClrListData(BaseHeaderBean oBaseHeaderBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepClrLstBO oHrmSepClrLstBO = new HrmSepClrLstBO(oUserInfo);
      return oHrmSepClrLstBO.saveData(oBaseHeaderBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public RecordMetaInfo getHrmSepClrTmplMstHdrMetaInfo(HrmSepClrTmplMstQVO oHrmSepEmpClrQVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oBO = new HrmSepClrTmplMstBO();
    return oBO.getHrmSepClrTmplMstHdrMetaInfo(oHrmSepEmpClrQVO);
  }
  
  public ArrayList getHrmSepClrTmplMstHdr(HrmSepClrTmplMstQVO oHrmSepEmpClrQVO, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oBO = new HrmSepClrTmplMstBO();
    return oBO.getHrmSepClrTmplMstHeaderInfo(oHrmSepEmpClrQVO, lStartPosition, lLastPosition);
  }
  
  public RecordMetaInfo getHrmSepClrTmplMstDtlMetaInfo(String lPrimaryKey) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oBO = new HrmSepClrTmplMstBO();
    return oBO.getHrmSepClrTmplMstDtlMetaInfo(lPrimaryKey);
  }
  
  public ArrayList getHrmSepClrTmplMstDtl(String lPrimaryKey, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oBO = new HrmSepClrTmplMstBO();
    return oBO.getHrmSepClrTmplMstDetailInfo(lPrimaryKey, lStartPosition, lLastPosition);
  }
  
  public String saveData(HrmSepClrTmplMstHdrBean oHrmSepEmpClrHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oBO = new HrmSepClrTmplMstBO(oUserInfo);
    return oBO.saveData((BaseHeaderBean)oHrmSepEmpClrHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
  }
  
  public LovVO getHrmSepClrLOV(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oHrmSepClrTmplMstBO = new HrmSepClrTmplMstBO();
    return oHrmSepClrTmplMstBO.getHrmSepClrLOV(oLovQueryVO);
  }
  
  public LovVO getHrmSepTmplLOV(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrTmplMstBO oHrmSepClrTmplMstBO = new HrmSepClrTmplMstBO();
    return oHrmSepClrTmplMstBO.getHrmSepTmplLOV(oLovQueryVO);
  }
  
  public LovVO getHrmSepEligLOV(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oHrmSepClrEmpBO = new HrmSepClrEmpBO();
    return oHrmSepClrEmpBO.getHrmSepEligLOV(oLovQueryVO);
  }
  
  public void updateSeparationEligRule(String sSql, String sId, String sUserId, String sUserSiteId) throws EnrgiseApplicationException, EnrgiseSystemException {
    try {
      HrmSepClrEmpBO oBO = new HrmSepClrEmpBO();
      oBO.updateSeparationEligRule(sSql, sId, sUserId, sUserSiteId);
    } catch (EnrgiseSystemException oSysEx) {
      this.ctx.setRollbackOnly();
      throw oSysEx;
    } catch (EnrgiseApplicationException oAppEx) {
      this.ctx.setRollbackOnly();
      throw oAppEx;
    } 
  }
  
  public RecordMetaInfo getHrmSepClrEmpHdrMetaInfo(HrmSepClrEmpQVO oHrmSepEmpClrQVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oBO = new HrmSepClrEmpBO();
    return oBO.getHrmSepClrEmpHdrMetaInfo(oHrmSepEmpClrQVO);
  }
  
  public ArrayList getHrmSepClrEmpHdr(HrmSepClrEmpQVO oHrmSepEmpClrQVO, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oBO = new HrmSepClrEmpBO();
    return oBO.getHrmSepClrEmpHeaderInfo(oHrmSepEmpClrQVO, lStartPosition, lLastPosition);
  }
  
  public RecordMetaInfo getHrmSepClrEmpDtlMetaInfo(String lPrimaryKey) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oBO = new HrmSepClrEmpBO();
    return oBO.getHrmSepClrEmpDtlMetaInfo(lPrimaryKey);
  }
  
  public ArrayList getHrmSepClrEmpDtl(String lPrimaryKey, long lStartPosition, long lLastPosition) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oBO = new HrmSepClrEmpBO();
    return oBO.getHrmSepClrEmpDetailInfo(lPrimaryKey, lStartPosition, lLastPosition);
  }
  
  public String saveData(HrmSepClrEmpHdrBean oHrmSepEmpClrHdrBean, Timestamp oWhenPicked, String sScreenName, String sScreenMode, boolean bHeaderDataChanged, ArrayList oDetailBeanArray, boolean bDetailDataChanged, Timestamp oDetailPicked, UserInfo oUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oBO = new HrmSepClrEmpBO(oUserInfo);
    return oBO.saveData((BaseHeaderBean)oHrmSepEmpClrHdrBean, oWhenPicked, sScreenName, sScreenMode, bHeaderDataChanged, oDetailBeanArray, bDetailDataChanged, oDetailPicked);
  }
  
  public LovVO getHrmSepClrEmpTmplLOV(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oHrmSepClrEmpBO = new HrmSepClrEmpBO();
    return oHrmSepClrEmpBO.getTmplLOV(oLovQueryVO);
  }
  
  public LovVO getHrmSepClrEmpEmpNoLOVQ(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oHrmSepClrEmpBO = new HrmSepClrEmpBO();
    return oHrmSepClrEmpBO.getEmpNoLOVQ(oLovQueryVO);
  }
  
  public LovVO getHrmSepClrEmpEmpNoLOVN(LovQueryVO oLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException {
    HrmSepClrEmpBO oHrmSepClrEmpBO = new HrmSepClrEmpBO();
    return oHrmSepClrEmpBO.getEmpNoLOVN(oLovQueryVO);
  }
}
