package wenrgise.hrms.ejb.facade;

import java.sql.Timestamp;
import java.util.ArrayList;
import javax.ejb.EJBLocalObject;
import wenrgise.common.bean.BaseHeaderBean;
import wenrgise.common.exception.EnrgiseApplicationException;
import wenrgise.common.exception.EnrgiseSystemException;
import wenrgise.common.utility.RecordMetaInfo;
import wenrgise.common.utility.UserInfo;
import wenrgise.common.vo.LovQueryVO;
import wenrgise.common.vo.LovVO;
import wenrgise.hrms.bean.HrmSepApplnHdrBean;
import wenrgise.hrms.bean.HrmSepCatMstHdrBean;
import wenrgise.hrms.bean.HrmSepClrEmpHdrBean;
import wenrgise.hrms.bean.HrmSepClrTmplMstHdrBean;
import wenrgise.hrms.bean.HrmSepOrderHdrBean;
import wenrgise.hrms.vo.HrmSepApplnQVO;
import wenrgise.hrms.vo.HrmSepCatMstQVO;
import wenrgise.hrms.vo.HrmSepClrEmpQVO;
import wenrgise.hrms.vo.HrmSepClrTmplMstQVO;
import wenrgise.hrms.vo.HrmSepOrderQVO;

public interface HrmSeparationFacadeLocal extends EJBLocalObject {
  RecordMetaInfo getHrmSepApplnHdrMetaInfo(HrmSepApplnQVO paramHrmSepApplnQVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepApplnHeaderInfo(HrmSepApplnQVO paramHrmSepApplnQVO, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepApplnDtlMetaInfo(String paramString) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepApplnDetailInfo(String paramString, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepApplnNoLOVdata(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepCategoryLOVdata(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveData(HrmSepApplnHdrBean paramHrmSepApplnHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String approveSepAppln(HrmSepApplnHdrBean paramHrmSepApplnHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String rejectSepAppln(HrmSepApplnHdrBean paramHrmSepApplnHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getSepEmpNoQLOVData(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getSepEmpNoNLOVData(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepOrderNoLOVdata(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepOrderApplnNoLOVdata(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepOrderApplnNoQLOVdata(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getSepApprNameLOVData(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepOrderHdrMetaInfo(HrmSepOrderQVO paramHrmSepOrderQVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepOrderHdr(HrmSepOrderQVO paramHrmSepOrderQVO, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepOrderDtlMetaInfo(String paramString) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepOrderDtl(String paramString, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveData(HrmSepOrderHdrBean paramHrmSepOrderHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String rejectSepOrder(HrmSepOrderHdrBean paramHrmSepOrderHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String approveSepOrder(HrmSepOrderHdrBean paramHrmSepOrderHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepCatHeaderMetaInfo(HrmSepCatMstQVO paramHrmSepCatMstQVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepCatHeader(HrmSepCatMstQVO paramHrmSepCatMstQVO, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveData(HrmSepCatMstHdrBean paramHrmSepCatMstHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSeparationCodeLOV(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepEligLOV(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepClrLstDtlMetaInfo() throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepClrLstDetailInfo(long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveClrListData(BaseHeaderBean paramBaseHeaderBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepClrTmplMstHdrMetaInfo(HrmSepClrTmplMstQVO paramHrmSepClrTmplMstQVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepClrTmplMstHdr(HrmSepClrTmplMstQVO paramHrmSepClrTmplMstQVO, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepClrTmplMstDtlMetaInfo(String paramString) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepClrTmplMstDtl(String paramString, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveData(HrmSepClrTmplMstHdrBean paramHrmSepClrTmplMstHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepClrLOV(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepTmplLOV(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepClrEmpHdrMetaInfo(HrmSepClrEmpQVO paramHrmSepClrEmpQVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepClrEmpHdr(HrmSepClrEmpQVO paramHrmSepClrEmpQVO, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  RecordMetaInfo getHrmSepClrEmpDtlMetaInfo(String paramString) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  ArrayList getHrmSepClrEmpDtl(String paramString, long paramLong1, long paramLong2) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  String saveData(HrmSepClrEmpHdrBean paramHrmSepClrEmpHdrBean, Timestamp paramTimestamp1, String paramString1, String paramString2, boolean paramBoolean1, ArrayList paramArrayList, boolean paramBoolean2, Timestamp paramTimestamp2, UserInfo paramUserInfo) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepClrEmpTmplLOV(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepClrEmpEmpNoLOVN(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
  
  LovVO getHrmSepClrEmpEmpNoLOVQ(LovQueryVO paramLovQueryVO) throws EnrgiseApplicationException, EnrgiseSystemException;
}
